##  Overview
On November 17, 2025, tech categories in the reference catalog were updated to the latest [_version 5.0.1 of the TBM Taxonomy_![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.tbmcouncil.org%2Ftaxonomy%2F "https://www.tbmcouncil.org/taxonomy/"). Key changes include:
  * “Artificial Intelligence“ is added as a new level 1 tech category, along with relevant level 2 and level 3 tech categories. It replaces the level 3 “Decision Intelligence and Automation“ tech category in the “Platform/Application” hierarchy.
  * “Sustainability and ESG“ is added as a new level 2 tech category.


You can import the updated tech categories from the reference catalog after the release. However, related fact sheets in your workspace won't update automatically. To keep your fact sheets in sync with the catalog and the latest TBM Taxonomy, you’ll need to apply a few changes to your workspace. To proceed, follow the steps in this migration guide.
If you don't take action, your tech categories will stay on the TBM Taxonomy version 4.
